package com.jz.dm.common.util;

import java.util.HashMap;
import java.util.Map;

/**
 * 结果码
 *
 */
public enum NotifyResultCode implements ResultCode {

    /** 处理成功 */
    SUCCESS("SUCCESS", "处理成功"),

    /** 处理失败 */
    FAILED("FAILED", "处理失败"),

    /** 未知异常 */
    UNKNOWN_EXCEPTION("UNKNOWN_EXCEPTION", "未知异常"),

    /** 数据库异常 */
    DATABASE_EXCEPTION("DATABASE_EXCEPTION", "数据库异常"),

    /** IO异常 */
    IO_EXCEPTION("IO_EXCEPTION", "IO异常"),

    /** 参数不能为空 */
    PARAM_CAN_NOT_NULL("PARAM_CAN_NOT_NULL", "参数不能为空"),

    /** 参数不能为空 */
    PARAM_CAN_NOT_EMPTY("PARAM_CAN_NOT_EMPTY", "参数不能为空"),

    /** 重复发送 */
    RETRANSMISSION("RETRANSMISSION", "重复发送"),

    /** 无效参数 */
    ILLEGAL_ARGUMENT("ILLEGAL_ARGUMENT", "无效参数"),

    /** 时间格式不合法*/
    ILLEGAL_DATE_FORMAT("ILLEGAL_DATE_FORMAT", "时间格式不合法"),

    ;

    /**
     * 初始化保存到map里方便根据code获取
     */
    private static Map<String, NotifyResultCode> RESULT_CODES = new HashMap<String, NotifyResultCode>();

    static {
        for (NotifyResultCode resultCode : NotifyResultCode.values()) {
            RESULT_CODES.put(resultCode.code, resultCode);
        }
    }

    /** 结果码 */
    private String           code;

    /** 结果码信息 */
    private String           msg;

    /** 结果分类 */
    private NotifyResultCode classification;

    /**
     * 构造函数
     *
     * @param code    结果码
     * @param msg     结果码信息
     */
    private NotifyResultCode(String code, String message) {
        this(code, message, null);
    }

    /**
     * 构造函数
     *
     * @param code    结果码
     * @param msg     结果码信息
     * @param classification 结果分组
     */
    private NotifyResultCode(String code, String msg, NotifyResultCode classification) {
        this.code = code;
        this.msg = msg;
        this.classification = classification;
    }

    /**
     * 通过枚举<code>code</code>获得枚举
     *
     * @param   code    结果码
     * @return  枚举
     */
    public static NotifyResultCode getResultCode(String code) {
        return RESULT_CODES.get(code);
    }

    /**
     * Getter method for property <tt>code</tt>.
     *
     * @return property value of code
     */
    @Override
    public String getCode() {
        return code;
    }

    /**
     * Setter method for property <tt>code</tt>.
     *
     * @param code value to be assigned to property code
     */
    public void setCode(String code) {
        this.code = code;
    }

    /**
     * Getter method for property <tt>msg</tt>.
     * 
     * @return property value of msg
     */
    @Override
    public String getMsg() {
        return msg;
    }

    /**
     * Setter method for property <tt>msg</tt>.
     * 
     * @param msg value to be assigned to property msg
     */
    public void setMsg(String msg) {
        this.msg = msg;
    }

    /**
     * Getter method for property <tt>classification</tt>.
     *
     * @return property value of classification
     */
    public NotifyResultCode getClassification() {
        return classification;
    }

    /**
     * Setter method for property <tt>classification</tt>.
     *
     * @param classification value to be assigned to property classification
     */
    public void setClassification(NotifyResultCode classification) {
        this.classification = classification;
    }

}
