package com.jz.dm.filter;

import com.jz.dm.common.exception.GatewayException;
import com.jz.dm.constant.Constants;
import com.jz.dm.model.GatewayRequest;
import com.jz.dm.model.GatewayResponse;
import com.jz.dm.model.enums.GatewayResultCode;
import org.springframework.stereotype.Component;

/**
 * 时间戳校验过滤器
 *
 * @author key
 */
@Component
public class CheckTimestampFilter extends AbstractFilter {

    //@Value("${api.skipFilter}")
    private boolean skipFilter;

    /**
     * 时间戳超时分钟，10分钟
     */
    private static final long max = 1000 * 60 * 10; //10分钟

    @Override
    protected void internalDoFilter(GatewayRequest request, GatewayResponse response, FilterChain chain) {
        if (!skipFilter) {
            String timestamp = request.getTimestamp();
            long time = 0;
            try {
                time = Long.valueOf(timestamp);
            } catch (Exception ex) {
                throw new GatewayException(GatewayResultCode.ILLEGAL_ARGUMENT);
            }
            if (System.currentTimeMillis() - time > max) {//无效时间戳
                throw new GatewayException(GatewayResultCode.ILLEGAL_TIMETEMP);
            }
        }
        chain.doFilter(request, response);
    }

    /** 
     * @see org.springframework.core.Ordered#getOrder()
     */
    @Override
    public int getOrder() {
        return Constants.FILTER_ORDER_5;
    }

    @Override
    public String getFilterName() {
        return "CheckTimestampFilter";
    }

}
