package com.jz.dm.filter;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.jz.dm.common.util.*;
import com.jz.dm.common.exception.SignatureException;
import com.jz.dm.common.util.StringUtil;
import com.jz.dm.constant.Constants;
import com.jz.dm.model.GatewayRequest;
import com.jz.dm.model.GatewayResponse;
import com.jz.dm.model.enums.GatewayResultCode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * 签名过滤器
 */
@Component
public class SignatureFilter extends AbstractFilter {

    private static final Logger LOGGER = LoggerFactory.getLogger(SignatureFilter.class);

   // @Autowired
  //  private IApiWhiteService apiWhiteService;
  //  @Value("${secret_private}")
  //  private String secretPrivate;

    private String encryptData;

    @Override
    protected void internalDoFilter(GatewayRequest request, GatewayResponse response,
                                    FilterChain chain) {
        try {
            chain.doFilter(request, response);
        } finally {
            String responseJson = null;
            String sign = StringUtil.EMPTY_STRING;
            String privatekey = null;
            if (StringUtil.isEmpty(request.getAppKey())) {
                return;
            }
            //ApiWhite apiWhite = apiWhiteService.byMerchantId(request.getAppId());
            //if (apiWhite == null) {
            //    return;
            //}
            //是否提供密码
            //boolean providePublicKey = false;
            //if ("0".equals(apiWhite.getProvideSecret())) {
            //    privatekey = apiWhite.getSecretKey();
            //} else if ("1".equals(apiWhite.getProvideSecret())) {
            //    privatekey = secretPrivate;
            //    providePublicKey = true;
            //}
            try {
                responseJson = JsonUtil.toJSONString(response.getResponse(),
                        PropertyNamingStrategy.SnakeCase);
                if (StringUtil.isNotEmpty(request.getSignType())) {
                    String charset = request.getCharset();
                    if (StringUtil.isEmpty(charset)) {
                        charset = Constants.CHARSET_UTF8;
                    }

                    //if (providePublicKey) {
                    //    sign = SignatureUtil.sign(convertResult(response.getResponse(), response, apiWhite), privatekey, charset, SignType.valueOf(request.getSignType()), SignatureUtil.SIGN_REQUEST, providePublicKey);
                    //} else {
                    //    sign = SignatureUtil.sign(convertResult(response.getResponse(), response, apiWhite), privatekey, charset, SignType.valueOf(request.getSignType()), SignatureUtil.SIGN_REQUEST, providePublicKey);
                    //}
                }
            } catch (JSONException e) {
                LogUtil.error(LOGGER, e,
                        "serializer response to json string error. response=" + response.getResponse());
                response.clearAttributes();
                response.setCode(OpenApiResultCode.RESPONSE_DATA_FORMAT_ERROR.getCode());
                response.setMsg(OpenApiResultCode.RESPONSE_DATA_FORMAT_ERROR.getMsg());
               // sign = signatureException(request, response, privatekey, providePublicKey);
            } catch (SignatureException ex) {
                LogUtil.error(LOGGER, ex,
                        "sign response error. response=" + response.getResponse());
                response.clearAttributes();
                response.setCode(ex.getResultCode().getCode());
                response.setMsg(ex.getResultCode().getMsg());
            } catch (Throwable ex) {
                LogUtil.error(LOGGER, ex,
                        "signatureFilter doFilter error. response=" + response.getResponse());
                response.clearAttributes();
                response.setCode(GatewayResultCode.UNKNOWN_EXCEPTION.getCode());
                response.setMsg(GatewayResultCode.UNKNOWN_EXCEPTION.getMsg());
              //  sign = signatureException(request, response, privatekey, providePublicKey);
            }
            response.setSign(sign);
            //if (apiWhite.getIsEncrypt()) {
            //    response.setEncryptData(encryptData);
            //}
        }
    }

    private Map<String, Object> convertResult(Map<String, Object> attributes, GatewayResponse response) {
        Map<String, Object> mapResult = new HashMap<>();
        mapResult.put("code", response.getCode());
        mapResult.put("msg", response.getMsg());
        Object code = attributes.get("code");
        Object msg = attributes.get("msg");
        attributes.remove("code");
        attributes.remove("msg");
        if (!CollectionUtils.isEmpty(attributes)) {
            mapResult.put("data", JsonUtil.toJSONString(attributes, PropertyNamingStrategy.SnakeCase));
            //if (apiWhite.getIsEncrypt()) {
            //    String string = (String) mapResult.get("data");
            //    try {
            //        RSAPrivateKey privateKey = RSAUtils.getPrivateKey(secretPrivate);
            //        String encrypt = RSAUtils.privateEncrypt(string, privateKey);
            //        mapResult.put("data", encrypt);
            //        encryptData = encrypt;
            //    } catch (Exception e) {
            //        e.printStackTrace();
            //    }
            //}
        }
        attributes.put("code", code);
        attributes.put("msg", msg);
        return mapResult;
    }

    private String signatureException(GatewayRequest request, GatewayResponse response,
                                      String privateKey, boolean providePublicKey) {
        String responseJson = null;
        String sign = StringUtil.EMPTY_STRING;
        try {
            responseJson = JsonUtil.toJSONString(response.getResponse(),
                    PropertyNamingStrategy.SnakeCase);
        } catch (JSONException e1) {
            LogUtil.error(LOGGER, e1,
                    "serializer response to json string error. response=" + response.getResponse());
            return sign;
        }
        try {
            sign = SignatureUtil.sign(responseJson, privateKey, request.getCharset(), SignType.valueOf(request.getSignType()), SignatureUtil.SIGN_REQUEST, providePublicKey);
        } catch (SignatureException ex) {
            LogUtil.error(LOGGER, ex, "sign response error. response=" + response.getResponse());
        }
        return sign;
    }

    /**
     * @see org.springframework.core.Ordered#getOrder()
     */
    @Override
    public int getOrder() {
        return Constants.FILTER_ORDER_0;
    }

    @Override
    public String getFilterName() {
        return "SignatureFilter";
    }

}
