package com.jz.dm.filter;
import com.jz.dm.common.util.HddHashMap;
import com.jz.dm.common.util.RSAUtils;
import com.jz.dm.constant.Constants;
import com.jz.dm.model.enums.RouteType;
import com.jz.dm.model.GatewayRequest;
import com.jz.dm.model.GatewayResponse;
import com.jz.dm.model.OpenApi;
import com.jz.dm.model.RequestContext;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.security.interfaces.RSAPublicKey;

/**
 * 验签过滤器
 */
@Slf4j
@Component
public class VerifySignFilter extends AbstractFilter {

    //@Autowired
    //private IApiWhiteService apiWhiteService;

    //@Value("${api.skipFilter}")
    private boolean skipFilter;

    private final static String CHARSET = "UTF-8";

    @Override
    protected void internalDoFilter(GatewayRequest request, GatewayResponse response,
                                    FilterChain chain) {
        HddHashMap params = new HddHashMap();
        params.put("app_id", request.getAppKey());
        params.put("method", request.getMethod());
        params.put("charset", request.getCharset());
        params.put("sign", request.getSign());
        params.put("sign_type", request.getSignType());
        params.put("timestamp", request.getTimestamp());
        params.put("version", request.getVersion());
        params.put("params", request.getParams());

        //ApiWhite apiWhite = apiWhiteService.byMerchantId(request.getAppId());
        //if (apiWhite != null) {
        //    String publicKey = apiWhite.getSecretKey();
        //
        //    if (!skipFilter) {
        //        boolean verify = SignatureUtil.verify(params, publicKey, request.getCharset(), SignType.valueOf(request.getSignType()));
        //        if (!verify) {
        //            throw new SignatureException(OpenApiResultCode.SIGN_VERIFY_ERROR);
        //        }
        //
        //        //参数解密
        //        if (apiWhite.getIsEncrypt()) {
        //            String decryptParams = decryptParams(request.getParams(), publicKey);
        //            request.setParams(decryptParams);
        //        }
        //    }
        //}

        // 后期再扩展
        OpenApi openApi = new OpenApi();
        openApi.setApplication("HDD_API_GATEWAY");
        openApi.setRouteType(RouteType.SRPING);
        RequestContext.getCurrentContext().set("openApi", openApi);

        chain.doFilter(request, response);
    }

    private String decryptParams(String params, String publicKey) {
        log.info("解密前请求参数,{}", params);
        try {
            RSAPublicKey key = RSAUtils.getPublicKey(publicKey);
            String decrypt = RSAUtils.publicDecrypt(params, key);
            log.info("解密后请求参数,{}", decrypt);
            return decrypt;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * @see org.springframework.core.Ordered#getOrder()
     */
    @Override
    public int getOrder() {
        return Constants.FILTER_ORDER_4;
    }

    @Override
    public String getFilterName() {
        return "VerifySignFilter";
    }
}
