package com.jz.dm.model;


import com.jz.dm.web.annotation.ParamName;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 *  api请求
 *
 * @author key
 */
public class GatewayRequest implements Serializable {

    /**
     * 分配的ID
     */
    @ParamName("app_key")
    private String                       appKey;

    /**
     * 接口名称
     */
    private String                       method;

    /**
     * 格式，目前仅支持JSON
     */
    private String                       format;

    /**
     * 请求使用的编码格式，如UTF-8,GBK,GB2312等
     */
    private String                       charset;

    /**
     * 生成签名字符串所使用的签名算法类型
     */
    @ParamName("sign_type")
    private String                       signType;

    /**
     * 请求参数的签名串
     */
    private String                       sign;

    /**
     * 发送请求的时间，格式"yyyy-MM-dd HH:mm:ss"
     */
    private String                       timestamp;

    /**
     * 调用的接口版本，固定为:1.0
     */
    private String                       version;

    ///**
    // * 回调通知地址
    // */
    //@ParamName("notify_url")
    //private String                       notifyUrl;

    ///**
    // * 返回地址
    // */
    //@ParamName("return_url")
    //private String                       returnUrl;

    /**
     * 请求参数,JSON格式
     */
    private String                       params;

    /**
     * 扩展属性
     */
    private final Map<String, Attribute> extAttributes = new HashMap<String, Attribute>();

    /**
     * Getter method for property <tt>appId</tt>.
     * 
     * @return property value of appId
     */
    public String getAppKey() {
        return appKey;
    }

    /**
     * Setter method for property <tt>appId</tt>.
     * 
     * @param appKey value to be assigned to property appId
     */
    public void setAppKey(String appKey) {
        this.appKey = appKey;
    }

    /**
     * Getter method for property <tt>method</tt>.
     * 
     * @return property value of method
     */
    public String getMethod() {
        return method;
    }

    /**
     * Setter method for property <tt>method</tt>.
     * 
     * @param method value to be assigned to property method
     */
    public void setMethod(String method) {
        this.method = method;
    }

    /**
     * Getter method for property <tt>format</tt>.
     * 
     * @return property value of format
     */
    public String getFormat() {
        return format;
    }

    /**
     * Setter method for property <tt>format</tt>.
     * 
     * @param format value to be assigned to property format
     */
    public void setFormat(String format) {
        this.format = format;
    }

    /**
     * Getter method for property <tt>charset</tt>.
     * 
     * @return property value of charset
     */
    public String getCharset() {
        return charset;
    }

    /**
     * Setter method for property <tt>charset</tt>.
     * 
     * @param charset value to be assigned to property charset
     */
    public void setCharset(String charset) {
        this.charset = charset;
    }

    /**
     * Getter method for property <tt>signType</tt>.
     * 
     * @return property value of signType
     */
    public String getSignType() {
        return signType;
    }

    /**
     * Setter method for property <tt>signType</tt>.
     * 
     * @param signType value to be assigned to property signType
     */
    public void setSignType(String signType) {
        this.signType = signType;
    }

    /**
     * Getter method for property <tt>sign</tt>.
     * 
     * @return property value of sign
     */
    public String getSign() {
        return sign;
    }

    /**
     * Setter method for property <tt>sign</tt>.
     * 
     * @param sign value to be assigned to property sign
     */
    public void setSign(String sign) {
        this.sign = sign;
    }

    /**
     * Getter method for property <tt>timestamp</tt>.
     * 
     * @return property value of timestamp
     */
    public String getTimestamp() {
        return timestamp;
    }

    /**
     * Setter method for property <tt>timestamp</tt>.
     * 
     * @param timestamp value to be assigned to property timestamp
     */
    public void setTimestamp(String timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * Getter method for property <tt>version</tt>.
     * 
     * @return property value of version
     */
    public String getVersion() {
        return version;
    }

    /**
     * Setter method for property <tt>version</tt>.
     * 
     * @param version value to be assigned to property version
     */
    public void setVersion(String version) {
        this.version = version;
    }

    /**
     * Getter method for property <tt>notifyUrl</tt>.
     * 
     * @return property value of notifyUrl
     */
    // public String getNotifyUrl() {
    //    return notifyUrl;
    //}

    /**
     * Setter method for property <tt>notifyUrl</tt>.
     * 
     * @param notifyUrl value to be assigned to property notifyUrl
     */
    //public void setNotifyUrl(String notifyUrl) {
    //    this.notifyUrl = notifyUrl;
    //}

    /**
     * Getter method for property <tt>returnUrl</tt>.
     * 
     * @return property value of returnUrl
     */
    //public String getReturnUrl() {
    //    return returnUrl;
    //}

    /**
     * Setter method for property <tt>returnUrl</tt>.
     * 
     * @param returnUrl value to be assigned to property returnUrl
     */
   // public void setReturnUrl(String returnUrl) {
   //     this.returnUrl = returnUrl;
   // }

    /**
     * Getter method for property <tt>params</tt>.
     * 
     * @return property value of params
     */
    public String getParams() {
        return params;
    }

    /**
     * Setter method for property <tt>params</tt>.
     * 
     * @param params value to be assigned to property params
     */
    public void setParams(String params) {
        this.params = params;
    }

    /**
     * 获取扩展属性
     * 
     * @param attributeName
     * @return
     */
    public Attribute getExtAttribute(String attributeName) {
        return extAttributes.get(attributeName);
    }

    /**
     * 设置属性
     * 
     * @param attribute
     */
    public void setExtAttribute(Attribute attribute) {
        if (attribute == null) {
            return;
        }
        extAttributes.put(attribute.name, attribute);
    }

    /**
     * Getter method for property <tt>extAttributes</tt>.
     * 
     * @return property value of extAttributes
     */
    public Map<String, Attribute> getExtAttributes() {
        return extAttributes;
    }

    /** 
     * @see Object#toString()
     */
    @Override
    public String toString() {
        return "GatewayRequest [appId=" + appKey + ", method=" + method + ", format=" + format
               + ", charset=" + charset + ", signType=" + signType + ", sign=" + sign
               + ", timestamp=" + timestamp + ", version=" + version
               + ", params=" + params + ", extAttributes="
               + extAttributes + "]";
    }

    public static class Attribute {

        /**
         *  熟悉名称
         */
        public String  name;

        /**
         * 属性值
         */
        public Object  value;

        /**
         * 是否传递到业务系统
         */
        public boolean isPass;

        public Attribute(String name, Object value) {
            this(name, value, false);
        }

        public Attribute(String name, Object value, boolean isPass) {
            this.name = name;
            this.value = value;
            this.isPass = isPass;
        }

        /**
         * @see Object#toString()
         */
        @Override
        public String toString() {
            return "Attribute [name=" + name + ", value=" + value + ", isPass=" + isPass + "]";
        }

    }

}
