package com.jz.dm.model;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.fasterxml.jackson.annotation.JsonIgnore;

import java.util.HashMap;
import java.util.Map;

/**
 * api响应
 *
 * @author key
 */
@JSONType(orders = { "response", "sign" })
public class GatewayResponse {

    /**
     * 结果码
     */
    private static final String       ATTRIBUTE_NAME_CODE = "code";

    /**
     * 结果消息
     */
    private static final String       ATTRIBUTE_NAME_MSG  = "msg";

    /**
     * 数据签名
     */
    private String                    sign;

    /**
     * 属性信息
     */
    private final Map<String, Object> attributes          = new HashMap<String, Object>();

    /**
     * 加密后参数密文
     */
    @JsonIgnore
    private String                    encryptData;

    public String getEncryptData() {
        return encryptData;
    }

    public void setEncryptData(String encryptData) {
        this.encryptData = encryptData;
    }

    /**
     * 默认构造函数
     */
    public GatewayResponse() {

    }

    /**
     * 构造函数，初始化属性信息
     * 
     * @param attributes
     */
    public GatewayResponse(Map<String, Object> attributes) {
        this.attributes.putAll(attributes);
    }

    @JSONField(serialize = false)
    public String getCode() {
        return (String) attributes.get(ATTRIBUTE_NAME_CODE);
    }

    public void setCode(String code) {
        attributes.put(ATTRIBUTE_NAME_CODE, code);
    }

    @JSONField(serialize = false)
    public String getMsg() {
        return (String) attributes.get(ATTRIBUTE_NAME_MSG);
    }

    public void setMsg(String msg) {
        attributes.put(ATTRIBUTE_NAME_MSG, msg);
    }

    @SuppressWarnings("unchecked")
    public <T> T getAttribute(String attributeName) {
        return (T) attributes.get(attributeName);
    }

    public void setAttribute(String attributeName, Object attributeValue) {
        attributes.put(attributeName, attributeValue);
    }

    public void setAttribute(Map<String, Object> attributes) {
        this.attributes.putAll(attributes);
    }

    public void clearAttributes() {
        attributes.clear();
    }

    public String getSign() {
        return sign;
    }

    public void setSign(String sign) {
        this.sign = sign;
    }

    public Map<String, Object> getResponse() {
        return attributes;
    }

    /**
     * @see Object#toString()
     */
    @Override
    public String toString() {
        return "GatewayResponse [sign=" + sign + ", attributes=" + attributes + "]";
    }

}
