package com.jz.dm.model.signtype;


import com.jz.dm.common.util.Base64;
import com.jz.dm.common.util.StreamUtil;
import org.apache.commons.lang3.StringUtils;

import java.io.*;
import java.security.*;
import java.security.interfaces.RSAPrivateKey;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;
import java.util.HashMap;
import java.util.Map;

public class SHA256WithRSA {
	public static final String SIGN_TYPE_RSA = "RSA";
	public static final String SIGN_SHA256RSA_ALGORITHMS = "SHA256WithRSA";

	/**
	 * RSA签名
	 * 
	 * @param content       待签名数据
	 * @param privateKey    商户私钥
	 * @param input_charset 编码格式
	 * @return 签名值
	 */
	public static String sign(String content, String privateKey, String input_charset) {
		try {
			PrivateKey priKey = getPrivateKeyFromPKCS8(SIGN_TYPE_RSA, new ByteArrayInputStream(privateKey.getBytes()));
			Signature signature = Signature.getInstance(SIGN_SHA256RSA_ALGORITHMS);

			signature.initSign(priKey);
			signature.update(content.getBytes(input_charset));
			return new String(Base64.encodeBase64(signature.sign()));
		} catch (Exception e) {

		}
		return null;
	}

	/**
	 * RSA验签名检查
	 * 
	 * @param content        待签名数据
	 * @param sign           签名值
	 * @param ali_public_key 支付宝公钥
	 * @param input_charset  编码格式
	 * @return 布尔值
	 */
	public static boolean verify(String content, String sign, String publicKey, String input_charset) {
		try {
			PublicKey pubKey = getPublicKeyFromX509(SIGN_TYPE_RSA, new ByteArrayInputStream(publicKey.getBytes()));
			Signature signature = Signature.getInstance(SIGN_SHA256RSA_ALGORITHMS);

			signature.initVerify(pubKey);
			signature.update(content.getBytes(input_charset));
			return signature.verify(Base64.decodeBase64(sign.getBytes()));
		} catch (Exception e) {
		}
		return false;
	}

	public static PrivateKey getPrivateKeyFromPKCS8(String algorithm, InputStream ins) throws Exception {
		if (ins == null || StringUtils.isEmpty(algorithm)) {
			return null;
		}

		KeyFactory keyFactory = KeyFactory.getInstance(algorithm);
		byte[] encodedKey = StreamUtil.readText(ins).getBytes();
		encodedKey = Base64.decodeBase64(encodedKey);
		return keyFactory.generatePrivate(new PKCS8EncodedKeySpec(encodedKey));
	}

	public static PublicKey getPublicKeyFromX509(String algorithm, InputStream ins) throws Exception {
		KeyFactory keyFactory = KeyFactory.getInstance(algorithm);
		StringWriter writer = new StringWriter();
		StreamUtil.io(new InputStreamReader(ins), writer);
		byte[] encodedKey = writer.toString().getBytes();
		encodedKey = Base64.decodeBase64(encodedKey);
		return keyFactory.generatePublic(new X509EncodedKeySpec(encodedKey));
	}

	private static java.util.Base64.Decoder decoder = java.util.Base64.getDecoder();
    private static java.util.Base64.Encoder encoder = java.util.Base64.getEncoder();
	public static Map<String, byte[]> generateKeyBytes() {
		try {
			KeyPairGenerator keyPairGenerator = KeyPairGenerator.getInstance(SIGN_TYPE_RSA);
			keyPairGenerator.initialize(2048);
			KeyPair keyPair = keyPairGenerator.generateKeyPair();
			RSAPublicKey publicKey = (RSAPublicKey) keyPair.getPublic();
			RSAPrivateKey privateKey = (RSAPrivateKey) keyPair.getPrivate();
			Map<String, byte[]> keyMap = new HashMap<String, byte[]>();
			keyMap.put("PUBLIC_KEY", publicKey.getEncoded());
			keyMap.put("PRIVATE_KEY", privateKey.getEncoded());
			return keyMap;
		} catch (NoSuchAlgorithmException e) {
			e.printStackTrace();
		}
		return null;
	}
	
	public static void main(String[] args) throws UnsupportedEncodingException {
		Map<String, byte[]> a = generateKeyBytes();
		String key = encoder.encodeToString(a.get("PRIVATE_KEY"));
		String pkey = encoder.encodeToString(a.get("PUBLIC_KEY"));
		
		String content = "abc";
		String sign = SHA1WithRSA.sign(content, key, "utf-8");
		System.out.println(SHA1WithRSA.verify(content, sign, pkey, "utf-8"));
	}
}
