package com.jz.common.utils;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.jz.common.constant.CommonConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;

/**
 * @ClassName: Result
 * @Description: 接口返回对象
 * @Author Bellamy
 * @Date 2020/11/27
 * @Version 1.0
 */
@Data
@ApiModel(value = "接口返回对象", description = "接口返回对象")
@JsonInclude(JsonInclude.Include.NON_NULL)
public class Result<T> implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 成功标志
     */
    @ApiModelProperty(value = "成功标志")
    private boolean success = true;

    /**
     * 返回处理消息
     */
    @ApiModelProperty(value = "返回处理消息")
    private String message;

    /**
     * 返回代码
     */
    @ApiModelProperty(value = "返回代码")
    private Integer code ;

    /**
     * 返回数据对象 data
     */
    @ApiModelProperty(value = "返回数据对象")
    private T data;

    /**
     * 时间戳
     */
    @ApiModelProperty(value = "时间戳")
    private long timestamp = System.currentTimeMillis();



    private Result(Integer code) {
        this.code = code;
    }
    /**
     * 构造函数
     * @param code 操作代码
     * @param data 数据对象
     */
    private Result(Integer code, T data) {
        this(code);
        this.data = data;
    }
    /**
     * 构造函数
     *
     * @param code
     *            操作代码
     * @param data
     *            数据对象
     * @param msg
     *            提示消息
     */
    private Result(Integer code, T data, ResultMsg msg) {
        this(code, data);
        this.message = msg.getMsg();
    }
    public Result setMsg(ResultMsg msg) {
        this.message = msg.getMsg();
        return this;
    }
    public Result setMsg(String msg) {
        this.message = msg;
        return this;
    }
    /**
     * 构造函数
     *
     * @param code
     *            操作代码
     * @param data
     *            数据对象
     * @param msg
     *            提示消息
     */

    private Result(Integer code, T data, String msg) {
        this(code, data);
        this.message = msg;
    }

    /**new Add*/
    public Result() {
        this.code = ResultCode.SUCCESS.getCode();
    }
    public static Result of_success(ResultMsg msg,Object data) {
        Result resultJson = new Result(ResultCode.SUCCESS.getCode(),data,msg);
        return resultJson;
    }
    public static Result of_success(Object data) {
        Result resultJson = new Result(ResultCode.SUCCESS.getCode(),data);
        resultJson.setMessage(ResultMsg.SUCCESS.getMsg());
        return resultJson;
    }
    public static Result of_success(ResultMsg msg) {
        Result resultJson = new Result(ResultCode.SUCCESS.getCode(),null,msg);
        return resultJson;
    }
    public static Result of_error(ResultMsg msg) {
        Result resultJson = new Result(ResultCode.FAILURE.getCode(),null,msg);
        return resultJson;
    }
    public static Result of_error(Object data) {
        Result resultJson = new Result(ResultCode.FAILURE.getCode(),data);
        return resultJson;
    }
    @Deprecated
    public static Result of_error(String msg) {
        Result resultJson = new Result(ResultCode.FAILURE.getCode(),null,msg);
        return resultJson;
    }
    public Result(boolean success, String message) {
        this.success = success;
        this.message = message;
    }
    public Result(boolean success, String message, Integer code) {
        this.success = success;
        this.message = message;
        this.code = code;
    }

    public Result(boolean success, String message, Integer code, T result) {
        this.success = success;
        this.message = message;
        this.code = code;
        this.data = result;
    }

    public Result(boolean success, String message, Integer code, T result, long timestamp) {
        this.success = success;
        this.message = message;
        this.code = code;
        this.data = result;
        this.timestamp = timestamp;
    }

    public static Result<Object> ok() {
        Result<Object> r = new Result<Object>();
        r.setSuccess(true);
        r.setCode(CommonConstant.SC_OK_200);
        r.setMessage("成功");
        return r;
    }

    public static Result<Object> ok(String msg) {
        Result<Object> r = new Result<Object>();
        r.setSuccess(true);
        r.setCode(CommonConstant.SC_OK_200);
        r.setMessage(msg);
        return r;
    }

    public static Result<Object> ok(Object data) {
        Result<Object> r = new Result<Object>();
        r.setSuccess(true);
        r.setCode(CommonConstant.SC_OK_200);
        r.setData(data);
        return r;
    }

    public static Result<Object> error(String msg) {
        return error(CommonConstant.SC_INTERNAL_SERVER_ERROR_500, msg);
    }

    public static Result<Object> error(int code, String msg) {
        Result<Object> r = new Result<Object>();
        r.setCode(code);
        r.setMessage(msg);
        r.setSuccess(false);
        return r;
    }

    public  Result<T> error500(String message) {
        this.message = message;
        this.code = CommonConstant.SC_INTERNAL_SERVER_ERROR_500;
        this.success = false;
        return this;
    }
    public Result<T> success(String message) {
        this.message = message;
        this.code = CommonConstant.SC_OK_200;
        this.success = true;
        return this;
    }

}
