package com.jz.dm.mall.moduls.controller.customer;


import com.jz.common.bean.MallCustomerApiDto;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.controller.customer.bean.CustomerDto;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.dm.mall.moduls.service.MallCustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.catalina.servlet4preview.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * @ClassName:
 * @Author: Carl
 * @Date: 2020/12/2
 * @Version:
 */
@RestController
@RequestMapping("/customer")
@Api(tags = "商城登陆api")
public class LoginController {
    /**
     * 服务对象
     */
    @Autowired
    private MallCustomerService mallCustomerService;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 登录功能
     *
     * @param username 账号
     * @param password 密码
     * @return
     */
    @PostMapping(value = "/login")
    @ApiOperation(value = "登录功能", notes = "登录功能")
    public Result<CustomerDto> login(String username, String password, HttpServletRequest request) throws Exception {
        // 手机
        String ph = "^[1][34578]\\d{9}$";
        // 如果是手机验证
        if (username.matches(ph)) {
            CustomerDto mallCustomer = mallCustomerService.selectByPhone(username, request);
            request.getSession().getAttribute("mallCustomer");
            if (mallCustomer != null) {
                if (mallCustomer.getCustomerPhone().equals(username) && mallCustomer.getPassword().equals(password)) {
                    return new Result<>(true, "登录成功！", StatusCode.OK);
                }
                return new Result<>(false, "用户名或密码错误！", StatusCode.ERROR);
            }
        }
        CustomerDto mallCustomer = mallCustomerService.selectByAccount(username, request);
        if (mallCustomer != null) {
            if (mallCustomer.getCustomerAccount().equals(username) && mallCustomer.getPassword().equals(password)) {
                return new Result<>(true, "登录成功！", StatusCode.OK);
            }
        }

        return new Result<>(false, "用户名或密码错误！", StatusCode.ERROR);
    }

    /**
     * 手机获取验证码
     *
     * @param paramMap
     * @return
     */
    @PostMapping(value = "/getCode")
    public Result loginCheck(@RequestParam(required = false) Map<String, String> paramMap) {
        // 获取手机号码
        String telephone = paramMap.get("telephone");
        String key = RedisMessageConstant.SENDTYPE_LOGIN + "_" + telephone;
        // 获取redis中key对应的值
        String codeInRedis = (String) redisTemplate.opsForValue().get(key);
        if (StringUtils.isEmpty(codeInRedis)) {
            return new Result(false, "请重新获取验证码!", StatusCode.ERROR);
        }
        // 判断验证码是否一致
        if (!codeInRedis.equals(paramMap.get("validateCode"))) {
            return new Result(false, "验证码不正确！", StatusCode.ERROR);
        }
        // 删除redis的验证码
        redisTemplate.delete(key);

        return new Result(true, "验证码正确！", StatusCode.OK);
    }

    /**
     * 手机号码校验
     *
     * @param telephone
     * @return
     */
    @GetMapping(value = "/phoneCheck")
    @ApiOperation(value = "手机号码校验接口", notes = "手机号码是否已注册")
    public Result phoneCheck(String telephone) {
        if (telephone == null) {
            return new Result(false, "请重新输入手机号！");
        }
        MallCustomer mallCustomer = mallCustomerService.selectByPhone(telephone);
        if (mallCustomer != null) {
            return new Result(false, "手机号码已注册！");
        }
        return new Result(true, "手机号码未注册！");
    }


    /**
     * 手机号码及用户名重复校验
     *
     * @param username
     * @param telephone
     * @param request
     * @return
     */
    @GetMapping(value = "/phoneUserCheck")
    @ApiOperation(value = "手机号用户名重复校验接口", notes = "手机号用户名是否重复")
    public Result phoneCheck(String username, String telephone, HttpServletRequest request) {
        String ph = "^[1][34578]\\d{9}$";
        if (telephone.matches(ph)) {
            MallCustomer mallCustomer = mallCustomerService.selectByPhone(telephone);
            if (mallCustomer != null) {
                if (mallCustomer.getCustomerPhone().equals(telephone)) {
                    return new Result(false, "手机号相同");
                }
            }
        }
        // 根据手机号查询用户信息
        CustomerDto mallCustomer = mallCustomerService.selectByAccount(username, request);
        if (mallCustomer != null) {
            if (mallCustomer.getCustomerAccount().equals(username)) {
                return new Result(false, "用户名相同!");
            }
        }
        return new Result(true, "用户名不同！");
    }
}
