package com.jz.dm.mall.moduls.controller.customer;

import com.baomidou.mybatisplus.extension.api.R;
import com.jz.common.base.BaseController;
import com.jz.common.base.CurrentUser;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import com.jz.common.utils.SessionUtils;
import com.jz.dm.mall.moduls.controller.customer.bean.CustomerDto;
import com.jz.dm.mall.moduls.entity.MallCustomer;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.service.MallCustomerService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.util.Map;

/**
 * 商城用户(MallCustomer)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:40
 */
@RestController
@RequestMapping("/mallCustomer")
@Api(tags = "商城用户api")
public class MallCustomerController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private MallCustomerService mallCustomerService;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 添加用户
     * @param paramMap
     * @return
     */
    @PostMapping("/saveCustomer")
    @ApiOperation(value = "注册用户", notes = "添加用户")
    public Result saveCustomer(@RequestParam(required = false) Map<String, String> paramMap, HttpServletRequest request) {
        if (paramMap != null) {
            String username = paramMap.get("username");
            String telephone = paramMap.get("telephone");
            String ph = "^[1][34578]\\d{9}$";
            if (telephone.matches(ph)) {
                MallCustomer mallCustomer = mallCustomerService.selectByPhone(telephone);
                if (mallCustomer != null) {
                    if (mallCustomer.getCustomerPhone().equals(telephone)) {
                        return new Result(false, "手机号相同");
                    }
                }
            }
            // 根据手机号查询用户信息
            CustomerDto mallCustomer = mallCustomerService.selectByAccount(username, request);
            if (mallCustomer != null) {
                if (mallCustomer.getCustomerAccount().equals(username)) {
                    return new Result(false, "用户名相同");
                }
            }
            mallCustomerService.saveCustomer(paramMap);
            return new Result(true, "注册成功！", StatusCode.OK);
        }
       return new Result(false, "注册失败！", StatusCode.ERROR);
    }


    /**
     * 获取用户信息
     * @return
     */
    @GetMapping("/getLoginUserName")
    @ApiOperation(value = "注册用户", notes = "添加用户")
    public Result getLoginUserName (HttpServletRequest request) {
        // 从session中获取id
        try {
            MallCustomer mallCustomer = (MallCustomer) SessionUtils.getUserCurrent(request,"mallCustomer");
            Long customerId = 1L;
//            Long customerId = mallCustomer.getCustomerId();
            MallCustomer user = mallCustomerService.selectByUser(customerId);
            return new Result(true, "获取用户信息成功！", StatusCode.OK, user);
        }catch (Exception e) {
            e.printStackTrace();
            return new Result(false, "获取用户信息失败");
        }
    }

    @PostMapping(value = "/updatePassword")
    public Result updatePassword(String oldPassword, String newPassword,HttpServletRequest request) throws Exception {
        // 获取用户信息
        MallCustomer mallCustomer = (MallCustomer) getLoginUserName(request).getData();
        // 如果密码一致
        if (mallCustomer.getPassword().equals(oldPassword)) {
            // 修改密码
            Long customerId = mallCustomer.getCustomerId();
            mallCustomerService.updatePassword(customerId, newPassword);
            return new Result(true, "密码修改成功");
        }
        return new Result(false, "密码修改失败");
    }
}