package com.jz.dm.mall.moduls.controller.finance;

import com.jz.common.base.BaseController;
import com.jz.common.bean.BasePageBean;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.utils.Result;
import com.jz.dm.mall.moduls.controller.finance.bean.*;
import com.jz.dm.mall.moduls.service.FinanceTradeFlowService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 企业客户交易流水(TFinanceTradeFlow)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:39
 */
@RestController
@RequestMapping("/financeTradeFlow")
@Api(tags = "商城--利润中心")
public class FinanceTradeFlowController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private FinanceTradeFlowService financeTradeFlowService;

    /**
     * 充值----获取企业账户余额
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/getAccountMoney")
    @ApiOperation(value = "充值----获取账户余额", notes = "获取账户余额，只有已审核（认证）企业才可以充值")
    public Result<FinanceCustomerAssetsDto> getAccountMoney(HttpServletRequest requset) throws Exception {
        Result<FinanceCustomerAssetsDto> result = new Result<>();
        //requset.getSession().getAttribute(""); //从session中获取商城用户的 id,和企业资产账户id
        Map map = new HashMap();
        map.put("assetsId", 1); //企业资产账户id
        map.put("departmentId", 1); //企业ID
        FinanceCustomerAssetsDto dto = financeTradeFlowService.queryAccountMoneyByMap(map);
        result.setData(dto);
        return result;
    }

    /**
     * 保存充值金额
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/getAccountMoney")
    @ApiOperation(value = "充值----保存充值金额", notes = "保存充值金额")
    @ApiParam()
    public Result<Object> uptAccountMoney(@RequestBody FinanceCustomerBalanceRequest customerBalanceRequest, HttpServletRequest requset) throws Exception {
        if (StringUtils.isEmpty(customerBalanceRequest.getAssetsId().toString())) { //企业资产id
            return Result.error("参数不能为空！");
        }
        if (StringUtils.isEmpty(customerBalanceRequest.getBalanceMoney().toString())) { //充值金额
            return Result.error("参数不能为空！");
        }
        Boolean str = financeTradeFlowService.uptAccountMoney(customerBalanceRequest);
        if (!str) {
            return Result.error("提交失败！");
        }
        return Result.ok("提交成功！");
    }

    /**
     * 充值----获取企业账户余额
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/cashOutAccountMoney")
    @ApiOperation(value = "提现----获取账户余额", notes = "获取账户余额")
    public Result<FinanceCustomerAssetsDto> getCashOutAccountMoney(HttpServletRequest requset) throws Exception {
        Result<FinanceCustomerAssetsDto> result = new Result<>();
        //requset.getSession().getAttribute(""); //从session中获取商城用户的 id,和企业资产账户id
        Map map = new HashMap();
        map.put("assetsId", 1); //企业资产账户id
        map.put("departmentId", 1); //企业ID
        FinanceCustomerAssetsDto dto = financeTradeFlowService.queryAccountMoneyByMap(map);
        result.setData(dto);
        return result;
    }

    /**
     * 是否存在提现为审核接口
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/cashOutAuditStutas")
    @ApiOperation(value = "提现----是否存在提现为审核接口", notes = "获取可提现金额")
    public Result<Object> getCashOutAuditStutas(HttpServletRequest requset) throws Exception {
        Result<Object> result = new Result<>();
        //requset.getSession().getAttribute(""); //从session中获取商城用户的 id,和企业资产账户id
        Map map = new HashMap();
        map.put("assetsId", 1); //企业资产账户id
        map.put("departmentId", 1); //企业ID
        FinanceCashOutDto dto = financeTradeFlowService.getCashOutAuditStutas(map);
        if (dto.getCashOutMoney() != null) {
            result.setData(dto.getCashOutMoney());
            result.setMessage("存在提现审核记录！");
        } else {
            result.setMessage("不存在！");
        }
        return result;
    }

    /**
     * 保存提现金额
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/addCashOutMoney")
    @ApiOperation(value = "提现----保存提现金额", notes = "保存提现金额")
    public Result<Object> addCashOutMoney(@RequestBody FinanceCashOutRequest financeCashOutRequest, HttpServletRequest requset) throws Exception {
        if (financeCashOutRequest.getCashOutMoney() == null) { //提现金额
            return Result.error("参数不能为空！");
        }
        Result<Object> result = financeTradeFlowService.addCashOutMoney(financeCashOutRequest);
        return result;
    }

    /**
     * 收支情况（分页查询）
     *
     * @author Bellamy
     * @since 2020-12-04
     */
    @PostMapping(value = "/receiveListInfo")
    @ApiOperation(value = "收支情况（分页查询）", notes = "收支情况（分页查询）")
    public PageInfoResponse<FinanceTradeFlowDto> queryPageList(@RequestBody BasePageBean pageBean, HttpServletRequest req) throws Exception {
        PageInfoResponse<FinanceTradeFlowDto> pageInfo = new PageInfoResponse<FinanceTradeFlowDto>();
        Map map = new HashMap();
        try {
            pageInfo = financeTradeFlowService.findListScTradeFlow(pageBean, req);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 点击查看--每天--收支情况（分页查询）
     *
     * @author Bellamy
     * @since 2020-12-04
     */
    @PostMapping(value = "/everyPageLisInfo")
    @ApiOperation(value = "点击查看--每天--收支情况（分页查询）", notes = "点击查看--每天--收支情况（分页查询）")
    public PageInfoResponse<EveryTradeFlowDto> queryEveryDayPageList(@RequestBody EveryTradeFlowRequest everyTradeFlowRequest, HttpServletRequest req) throws Exception {
        PageInfoResponse<EveryTradeFlowDto> pageInfo = new PageInfoResponse<EveryTradeFlowDto>();

        if (everyTradeFlowRequest.getCreTime() == null || "".equals(everyTradeFlowRequest.getCreTime())) {
            pageInfo.setMessage("参数为空");
            pageInfo.setCode(Constants.FAILURE_CODE);
            return pageInfo;
        }
        Map map = new HashMap();
        try {
            pageInfo = financeTradeFlowService.findListEveryDayScInfo(everyTradeFlowRequest, req);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }
}