package com.jz.dm.mall.moduls.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.dm.mall.moduls.controller.order.bean.*;
import com.jz.dm.mall.moduls.mapper.OrderDao;
import com.jz.dm.mall.moduls.service.OrderService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * 订单表(TOrder)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:40
 */
@Service("orderService")
@Transactional
public class OrderServiceImpl implements OrderService {

    @Autowired
    private OrderDao orderDao;

    @Override
    public PageInfoResponse<OrderDto> findList(OrderRequest order, HttpServletRequest req) throws Exception {
        PageInfoResponse<OrderDto> pageInfoResponse = new PageInfoResponse<>();

        Map<String, Object> param = new HashMap<>();
        //数据编号
        if (StringUtils.isNotEmpty(order.getOrderNumber())) {
            param.put("orderNumber", order.getOrderNumber());
        }
        //购买（订单）方式
        if (StringUtils.isNotEmpty(order.getPurchaseMethod())) {
            param.put("purchaseMethod", order.getPurchaseMethod());
        }
        //数据类型
        if (StringUtils.isNotEmpty(order.getDataType())) {
            param.put("dataType", order.getDataType());
        }
        //数据商品名称
        if (!StringUtils.isEmpty(order.getDataName())) {
            param.put("dataName", order.getDataName());
        }
        //商品分类id（行业）
        if (!StringUtils.isEmpty(order.getCategoryId())) {
            param.put("categoryId", order.getCategoryId());
        }

        PageHelper.startPage(order.getPageNum(), order.getPageSize());
        List<OrderDto> list = orderDao.findList(param);
        PageInfo<OrderDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(Constants.SUCCESS_CODE);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    @Override
    public OrderDto getOrderDetail(String orderId) throws Exception {
        OrderDto orderDto = null;

        if (StringUtils.isNotEmpty(orderId)) {
            orderDto = orderDao.getOrderDetail(orderId);
            if (orderDto != null) {
                /*SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                long effectTimes = orderDto.getTakeEffectTime().getTime(); //开始生效日期
                long invalidTimes = orderDto.getInvalidTime().getTime();   //有效结束日期
                long syTime = invalidTimes - effectTimes; //有效时间毫秒数
                Date mtime = new Date(syTime);
                int month = mtime.getMonth();*/

                //getEffectTime(orderDto.getTakeEffectTime(), orderDto.getInvalidTime());
            }
        }
        return orderDto;
    }

    @Override
    public Map getApiInterfaceDetail(Map params) throws Exception {
        Map returnMap = new HashMap();
        DataGoodsApiDto dataGoodsApi = new DataGoodsApiDto(); //接口文档信息
        List<DataGoodsApiParamsDto> goodsApiParamsLst = new ArrayList<>(); //接口参数信息

        if (params.size() > 0) {
            List<DataGoodsApiDto> dataGoodsApiDto = orderDao.getApiInterface(params);//接口文档信息
            dataGoodsApi = dataGoodsApiDto.get(0);
            Long goodsApiId = dataGoodsApi.getGoodsApi();
            goodsApiParamsLst = orderDao.getApiParamsInfo(goodsApiId);//接口参数信息
        }
        returnMap.put("dataGoodsApi", dataGoodsApi);
        returnMap.put("goodsApiParamsLst", goodsApiParamsLst);
        return returnMap;
    }


    public void getEffectTime(Date takeEffectTime, Date invalidTime) {
        Calendar startTime = Calendar.getInstance();
        startTime.setTime(takeEffectTime); //开始日期

        Calendar endCalendar = Calendar.getInstance();
        endCalendar.setTime(invalidTime); //结束日期
        int hour = endCalendar.get(Calendar.HOUR_OF_DAY) - startTime.get(Calendar.HOUR_OF_DAY);
        int day = endCalendar.get(Calendar.DAY_OF_MONTH) - startTime.get(Calendar.DAY_OF_MONTH);
        int month = endCalendar.get(Calendar.MONTH) - startTime.get(Calendar.MONTH);
        int year = endCalendar.get(Calendar.YEAR) - startTime.get(Calendar.YEAR);
        // 按照减法原理，先day相减，不够向month借；然后month相减，不够向year借；最后year相减。
        if (day < 0) {
            month -= 1;
            endCalendar.add(Calendar.MONTH, -1);// 得到上一个月，用来得到上个月的天数。

            day = day + endCalendar.getActualMaximum(Calendar.DAY_OF_MONTH);
        }
        if (month < 0) {
            month = (month + 12) % 12;
            year--;
        }
        System.out.println("结果：" + year + "年" + month + "月" + day + "天");
        /*for (int i = 0; i < month; i++) {
            endCalendar.add(Calendar.MONTH, -1);// 得到上一个月，用来得到上个月的天数。

            day = day + endCalendar.getActualMaximum(Calendar.DAY_OF_MONTH);
        }
        System.out.println("过去时间与现在有：" + year + "年" + "" + day + "天");*/
    }
}