package com.jz.manage.moduls.controller.finance;

import com.jz.common.bean.BasePageBean;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.finance.platForm.*;
import com.jz.manage.moduls.service.PlatformTradeFlowInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 平台交易流水(TPlatformTradeFlowInfo)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:44
 */
@RestController
@RequestMapping("platformTradeFlowInfo")
@Api(tags = "平台--利润中心")
public class PlatformTradeFlowInfoController extends BaseController {

    private static final Logger logger = LoggerFactory.getLogger(PlatformTradeFlowInfoController.class);
    /**
     * 服务对象
     */
    @Autowired
    private PlatformTradeFlowInfoService platformTradeFlowInfoService;

    /**
     * 获取平台累计收入和企业总数
     *
     * @author Bellamy
     * @since 2020-12-03
     */
    @GetMapping(value = "/platFormMoneyAndDepart")
    @ApiOperation(value = "财务管理---累计收入和企业总数", notes = "累计收入和企业总数")
    public Result<PlatFormMoneyAndDepartDto> getPlatFormMoneyAndDepart(HttpServletRequest requset) throws Exception {
        Result<PlatFormMoneyAndDepartDto> result = new Result<>();

        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());

        PlatFormMoneyAndDepartDto dto = platformTradeFlowInfoService.queryPlatFormMoneyAndDepart(map);
        result.setData(dto);
        return result;
    }

    /**
     * 财务管理---我的订单
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/orderCountList")
    @ApiOperation(value = "财务管理---我的订单", notes = "我的订单")
    public PageInfoResponse<OrderCountInfoDto> findList(@RequestBody BasePageBean pageBean, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<OrderCountInfoDto> pageInfo = new PageInfoResponse<OrderCountInfoDto>();
        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());
        try {
            pageInfo = platformTradeFlowInfoService.findListOrderCount(pageBean, httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }

        return pageInfo;
    }

    /**
     * 财务管理--交易明细
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/tradeDetilList")
    @ApiOperation(value = "财务管理--交易明细", notes = "交易明细")
    public PageInfoResponse<TradeDetilDto> getFinanceTradeDetil(@RequestBody TradeDetilRequest tradeDetilRequest, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<TradeDetilDto> pageInfo = new PageInfoResponse<TradeDetilDto>();
        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());
        try {
            pageInfo = platformTradeFlowInfoService.findListFinanceTradeDetil(tradeDetilRequest, httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 提现管理--分页列表
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/cashOutList")
    @ApiOperation(value = "提现管理--分页列表", notes = "分页列表")
    public PageInfoResponse<CashOutListDto> getFinanceCashOutList(@RequestBody CashOutListRequest cashOutListRequest, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<CashOutListDto> pageInfo = new PageInfoResponse<CashOutListDto>();
        Map map = new HashMap();
        //从session中获取平台用户id
        //SysUserDto user = (SysUserDto) SessionUtils.getUserCurrent(requset,"sysUser");
        //map.put("userId", user.getUserId());
        try {
            pageInfo = platformTradeFlowInfoService.findListFinanceCashOut(cashOutListRequest, httpRequest);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(Constants.FAILURE_CODE);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 提现管理--提现详情
     *
     * @return
     * @author Bellamy
     * @since 2020-12-06
     */
    @PostMapping(value = "/cashOutInfoById")
    @ApiOperation(value = "提现管理--提现详情", notes = "提现详情")
    public Result<Object> getFinanceCashOutInfoById(@RequestParam(value = "cashOutId") String cashOutId, HttpServletRequest httpRequest) throws Exception {
        Result<Object> result = new Result<>();
        if (StringUtils.isEmpty(cashOutId)) {
            return Result.error("参数不能为空！");
        }
        CashOutInfoDto dto = platformTradeFlowInfoService.queryCashOutByid(cashOutId);
        result.setData(dto);
        return result;
    }

    /**
     * 提现管理--提现审核
     *
     * @return
     * @author Bellamy
     * @since 2020-12-06
     */
    @PostMapping(value = "/cashOutInfoAudit")
    @ApiOperation(value = "提现管理--提现审核", notes = "提现审核")
    public Result<Object> getCashOutInfoAudit(@RequestBody CashOutAuditRequest cashOutAuditRequest, HttpServletRequest httpRequest) throws Exception {
        Result<Object> result = new Result<>();
        if (StringUtils.isEmpty(cashOutAuditRequest.getCashOutId())) {
            return Result.error("参数不能为空！");
        }
        if (StringUtils.isEmpty(cashOutAuditRequest.getAuditStatus())) {
            return Result.error("参数不能为空！");
        }
        Result<Object> dto = platformTradeFlowInfoService.uptCashOutInfoAuditByid(cashOutAuditRequest);
        return dto;
    }

}