package com.jz.manage.moduls.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.exception.ResponseException;
import com.jz.common.utils.DateUtils;

import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.customer.bean.dto.CompanyDetailsDto;
import com.jz.manage.moduls.controller.customer.bean.dto.EnterpriseAuditDto;
import com.jz.manage.moduls.controller.customer.bean.request.EnterpriseAuditRequest;

import com.jz.manage.moduls.controller.customer.bean.request.SaveCustomerRequest;
import com.jz.manage.moduls.entity.Department;
import com.jz.manage.moduls.entity.FinanceCustomerAssets;
import com.jz.manage.moduls.entity.FinanceCustomerBalance;
import com.jz.manage.moduls.entity.MallCustomer;
import com.jz.manage.moduls.mapper.DepartmentDao;
import com.jz.manage.moduls.mapper.FinanceCustomerAssetsDao;
import com.jz.manage.moduls.mapper.FinanceCustomerBalanceDao;
import com.jz.manage.moduls.mapper.MallCustomerDao;
import com.jz.manage.moduls.service.DepartmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 企业(TDepartment)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
@Service("departmentService")
public class DepartmentServiceImpl implements DepartmentService {
    @Autowired
    private DepartmentDao tDepartmentDao;

    @Autowired
    private FinanceCustomerAssetsDao financeCustomerAssetsDao;

    @Autowired
    private MallCustomerDao mallCustomerDao;

    @Autowired
    private FinanceCustomerBalanceDao financeCustomerBalanceDao;

    /**
     * 条件查询企业审核信息列表
     *
     * @param auditRequest
     * @param req
     * @return
     */
    @Override
    public PageInfoResponse<EnterpriseAuditDto> findList(EnterpriseAuditRequest auditRequest, HttpServletRequest req) {
        PageInfoResponse<EnterpriseAuditDto> pageInfoResponse = new PageInfoResponse<>();
        Map<String, Object> param = new HashMap<>();

        // 企业地址
        if (!StringUtils.isEmpty(auditRequest.getRegisteredAddress())) {
            param.put("registeredAddress", auditRequest.getRegisteredAddress());
        }

        // 企业名
        if (!StringUtils.isEmpty(auditRequest.getDepartmentName())) {
            param.put("departmentName", auditRequest.getDepartmentName());
        }

        // 联系人电话
        if (auditRequest.getCustomerPhone() != null) {
            param.put("customerPhone", auditRequest.getCustomerPhone());
        }

        // 审核状态
        if (!StringUtils.isEmpty(auditRequest.getAuditStatus())) {
            param.put("auditStatus", auditRequest.getAuditStatus());
        }
        PageHelper.startPage(auditRequest.getPageNum(), auditRequest.getPageSize());
        List<EnterpriseAuditDto> list = tDepartmentDao.findList(param);
        PageInfo<EnterpriseAuditDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(Constants.SUCCESS_CODE);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /**
     * 主键获取用户企业详情信息
     * @param id
     * @return
     */
    @Override
    public CompanyDetailsDto selectById(Long id) {
        CompanyDetailsDto CompanyDetails = tDepartmentDao.selectById(id);
        return CompanyDetails;
    }

    /**
     * 企业审核信息
     *
     * @param id
     */
    @Override
    @Transactional
    public void audit(Long id) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("department_id", id);
        // 获取企业详细信息
        Department department = tDepartmentDao.selectOne(queryWrapper);
//        if (department.getAuditStatus().equals("02") ) {
//            throw ResponseException.of(ResultCode.FAILURE, "已审核！不用在审核！");
//        }
        // 从session获取商城用户id

        // 更新信息: 将企业审核状态改为已审核，企业信息更新
        department.setAuditStatus("02");
        department.setAuditPerson("1");
        department.setAuditTime(DateUtils.getToday());
        department.setUptTime(DateUtils.getToday());
        department.setUptPerson(department.getUptPerson());
        tDepartmentDao.updateById(department);

        // 新增企业客户资产
        FinanceCustomerAssets financeCustomerAssets = new FinanceCustomerAssets();
        financeCustomerAssets.setDepartmentId(department.getDepartmentId());
        financeCustomerAssets.setCreTime(DateUtils.getToday());
        financeCustomerAssets.setCrePerson("1");
        financeCustomerAssetsDao.insert(financeCustomerAssets);

    }

    /**
     * 添加用户
     *
     * @param
     */
    @Override
    @Transactional()
    public Result add(SaveCustomerRequest saveCustomerReq) {
        // 校验信息
        Result s = userCheck(saveCustomerReq);
        boolean success = s.isSuccess();
        if (!success) {
            return Result.error("添加用户失败！");
        }
        // 保存企业信息
        Long departmentId = saveCompany(saveCustomerReq);
        if (departmentId != null) {
            // 保存账号信息
            MallCustomer mallCustomer = new MallCustomer();
            mallCustomer.setDepartmentId(departmentId);
            mallCustomer.setCustomerAccount(saveCustomerReq.getCustomerAccount());
            mallCustomer.setCustomerPhone(saveCustomerReq.getCustomerPhone());
            mallCustomer.setPassword(saveCustomerReq.getPassword());
            mallCustomer.setCreTime(DateUtils.getToday());
            mallCustomer.setCustomerPoint(0L);
            mallCustomer.setCrePerson("1");
            mallCustomer.setDelFlag("N");
            mallCustomerDao.insert(mallCustomer);
            System.out.println(mallCustomer.getCustomerId());

            // 如果充值金额不为空
            if (saveCustomerReq.getBalanceMoney() != null) {
                // 新增一条企业客户资产
                FinanceCustomerAssets assets = new FinanceCustomerAssets();
                assets.setCrePerson(mallCustomer.getCustomerId() + "");
                if (departmentId != null) {
                    try {
                        assets.setDepartmentId(departmentId);
                        assets.setUseMoney(saveCustomerReq.getBalanceMoney());
                        assets.setTotalMoney(saveCustomerReq.getBalanceMoney());
                        assets.setCreTime(DateUtils.getToday());
                        assets.setCrePerson(mallCustomer.getCustomerId() + "");
                        assets.setDelFlag("N");
                        financeCustomerAssetsDao.insert(assets);
                    }catch (Exception e) {
                        throw ResponseException.of(ResultCode.FAILURE, "新增企业资产失败！");
                    }
                }
                // 新增一条充值记录表
                // 获取最新的资产id
                Long assetsId = assets.getAssetsId();
                FinanceCustomerBalance balance = new FinanceCustomerBalance();
                if (assetsId != null) {
                    try{
                        balance.setAssetsId(assetsId);
                        balance.setBalanceMoney(saveCustomerReq.getBalanceMoney());
                        balance.setCrePerson(mallCustomer.getCustomerId() + "");
                        balance.setCreTime(DateUtils.getToday());
                        balance.setAuditStatus("02");
                        balance.setDelFlag("N");
                        financeCustomerBalanceDao.insert(balance);
                    }catch (Exception e) {
                        throw ResponseException.of(ResultCode.FAILURE, "新增充值记录失败！");
                    }
                }
            }
        }
        return Result.of_success("添加用户成功！");
    }

    /**
     * 保存企业信息
     * @param saveCustomerReq
     */
    private Long saveCompany(SaveCustomerRequest saveCustomerReq) {
        Department department = new Department();
        // 添加创建人/创建时间
        department.setCrePerson("1");
        department.setCreTime(DateUtils.getToday());
        // 基本信息
        department.setDepartmentName(saveCustomerReq.getDepartmentName());
        department.setRegisteredAddress(saveCustomerReq.getRegisteredAddress());
        // 企业信息
        department.setUnifiedCreditCode(saveCustomerReq.getUnifiedCreditCode());
        department.setBusinessLicense(saveCustomerReq.getBusinessLicense());
        department.setBankAddress(saveCustomerReq.getBankAddress());
        department.setBankCardNumber(saveCustomerReq.getBankCardNumber());
        // 联系人信息
        department.setLinkman(saveCustomerReq.getLinkman());
        department.setTelephone(saveCustomerReq.getTelephone());
        // 已审核
        department.setAuditStatus("02");
        tDepartmentDao.insert(department);
        return department.getDepartmentId();
    }

    /**
     * 校验企业/账号是否存在
     * @param saveCustomerReq
     */
    private Result userCheck(SaveCustomerRequest saveCustomerReq) {
        // 校验公司是否已存在
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("unified_credit_code", saveCustomerReq.getUnifiedCreditCode());
        Department department = tDepartmentDao.selectOne(queryWrapper);
        // 如果为空
        if (department != null) {
            return Result.error("企业已存在！");
        }
        // 校验账号信息
        Map<String, Object> accountMap = new HashMap<>();
        accountMap.put("customerAccount", saveCustomerReq.getCustomerAccount());
        // 查询用户是否存在
        MallCustomer accountUser = mallCustomerDao.selectByUser(accountMap);
        if (accountUser != null) {
            return Result.error("用户已存在！");
        }

        Map<String, Object> phoneMap = new HashMap<>();
        phoneMap.put("customerPhone", saveCustomerReq.getCustomerPhone());
        // 查询用户是否存在
        MallCustomer phoneUser = mallCustomerDao.selectByUser(phoneMap);
        if (phoneUser != null) {
            return Result.error("用户已存在！");
        }
        return Result.ok();
    }
}