package com.jz.manage.moduls.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.entity.SysUser;
import com.jz.common.enums.UserTypeEnum;
import com.jz.common.utils.SessionUtils;
import com.jz.manage.moduls.controller.sys.bean.SysUserDto;
import com.jz.manage.moduls.mapper.SysUserDao;
import com.jz.manage.moduls.service.SysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * 平台系统用户表(SysUser)表服务实现类
 *
 * @author Bellamy
 * @since 2020-11-29 14:30:26
 */
@Service("sysUserService")
@Transactional
public class SysUserServiceImpl implements SysUserService {

    @Autowired
    private SysUserDao sysUserDao;

    @Autowired
    private RedisTemplate redisTemplate;


    @Override
    public SysUser selectByUsername(String username, HttpServletRequest request) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("account", username);
        SysUser sysUser = sysUserDao.selectOne(queryWrapper);
        if (sysUser != null) {
            SysUserDto SysUserDto = new SysUserDto();
            // 赋值
            SysUserDto.setUserId(sysUser.getUserId());
            SysUserDto.setOrgId(sysUser.getOrgId());
            SysUserDto.setAccount(sysUser.getAccount());
            SysUserDto.setUserTypeEnum(UserTypeEnum.BACKGROUND_ROLE);
            SysUserDto.setUserName(sysUser.getUserName());
            // 存入到session
            SessionUtils.setUserCurrent("sysUser", SysUserDto, request);
            // 存入到redis
            redisTemplate.opsForValue().set("user_" + RedisMessageConstant.SENDTYPE_LOGIN_SYS, SysUserDto, 3, TimeUnit.DAYS);
        }
        return sysUser;
        }

    @Override
    public SysUser selectByPhone(String username, HttpServletRequest request) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("telephone", username);
        SysUser sysUser = sysUserDao.selectOne(queryWrapper);
        if (sysUser != null) {
            SysUserDto SysUserDto = new SysUserDto();
            // 赋值
            SysUserDto.setUserId(sysUser.getUserId());
            SysUserDto.setOrgId(sysUser.getOrgId());
            SysUserDto.setAccount(sysUser.getAccount());
            SysUserDto.setUserTypeEnum(UserTypeEnum.BACKGROUND_ROLE);
            SysUserDto.setUserName(sysUser.getUserName());
            // 存入到session
            SessionUtils.setUserCurrent("sysUser", SysUserDto, request);
            // 存入到redis
            redisTemplate.opsForValue().set("user_" + RedisMessageConstant.SENDTYPE_LOGIN_SYS, SysUserDto, 3, TimeUnit.DAYS);
        }
        return sysUser;
    }

    @Override
    public Map<String, Object> getUserRoleByAccount(String account) {
        Set<String> roleSet = new HashSet<>();
        Set<String> roleMenuSet = new HashSet<>();
        //查询用户拥有的角色
        List<Map> list = sysUserDao.getUserRoleByAccount(account);
        if (list.size() > 0 && list != null) {
            for (Map map : list) {
                roleSet.add(map.get("roleName").toString());
                roleSet.add(map.get("roleId").toString());
                roleMenuSet.add(map.get("menuId").toString());
                roleMenuSet.add(map.get("menuName").toString());
                roleMenuSet.add(map.get("parentId").toString());
                roleMenuSet.add(map.get("url").toString());
            }
        }
        Map<String, Object> userInfo = new HashMap<>();
        userInfo.put("roleSet", roleSet);
        userInfo.put("roleMenuSet", roleMenuSet);
        return userInfo;
    }
}